function Run()
{
    Clear-Host
    CheckAdminPrivileges

    $serviceName = "CICBv2"
    $nssmPath = ".\win32\nssm.exe"
    $appPath = 'C:\Program Files (x86)\CICBv2\Server\server.exe'

    while($true)
    {
        DisplayMenu
        $option = $null
        $option = Read-Host "Option"

        if($option -eq 1 -OR $option -eq 2)
        {
            RemoveAutostart
            StopRunningServer $appPath
            StopExistingService $nssmPath $serviceName
            RemoveService $nssmPath $serviceName
            Start-Sleep -Seconds 3
            InstallService $nssmPath $serviceName $appPath
            SetServiceConfigurations $nssmPath $serviceName $option
            Start-Sleep -Seconds 5
            StartService $nssmPath $serviceName
            CheckServiceStatus $serviceName
        }

        if($option -eq 3)
        {
            RemoveAutostart
            StopRunningServer $appPath
            StopExistingService $nssmPath $serviceName
            RemoveService $nssmPath $serviceName
            Start-Sleep -Seconds 5
            CheckServiceStatus $serviceName
        }

        if($option -eq 0)
        {
            Exit
        }
        
        if($option -lt 0 -or $option -gt 3){
            Write-Host "Please choose a valid option!`n" -ForegroundColor Red
        }
    }
}


# Check admin privileges
function CheckAdminPrivileges()
{
    Write-Host "CheckAdminPrivileges()`n" -ForegroundColor Yellow
    # Ensure the script is run with administrative privileges
    if (-not ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")) {
        Write-Host "`nPlease run this script with administrative permissions." -ForegroundColor Red
        Pause
        Exit
    }
}


function DisplayMenu()
{
    Write-Host "`nCICB Service Installer" -ForegroundColor Cyan
    Write-Host "v1.01`n" -ForegroundColor Cyan
    Write-Host "[1] Install Service (Local System Account)" -ForegroundColor Yellow
    Write-Host "[2] Install Service (Your User Account)" -ForegroundColor Yellow
    Write-Host "[3] Uninstall Service" -ForegroundColor Yellow
    Write-Host "[0] Exit`n" -ForegroundColor Yellow
}


# Remove autostart
function RemoveAutostart (){
    # Remove autostart registry entries
    Write-Host "RemoveAutostart()" -ForegroundColor Yellow
    try {
        Remove-ItemProperty -Path "HKCU:\Software\Microsoft\Windows\CurrentVersion\Run" -Name "CICBAgent.exe" -ErrorAction SilentlyContinue
        Remove-ItemProperty -Path "HKLM:\Software\Microsoft\Windows\CurrentVersion\Run" -Name "CICBAgent.exe" -ErrorAction SilentlyContinue
        Remove-ItemProperty -Path "HKCU:\Software\Microsoft\Windows\CurrentVersion\Run" -Name "CICBServer.exe" -ErrorAction SilentlyContinue
        Remove-ItemProperty -Path "HKLM:\Software\Microsoft\Windows\CurrentVersion\Run" -Name "CICBServer.exe" -ErrorAction SilentlyContinue
        Write-Host "Successfully removed autostart entries.`n" -ForegroundColor Green
    } catch {
        Write-Host "Failed to remove some autostart entries: $_`n" -ForegroundColor Red
    }
}


# Remove the existing service
function RemoveService($nssmPath, $serviceName)
{
    Write-Host "RemoveService()" -ForegroundColor Yellow
    try {
        Start-Process -FilePath $nssmPath -ArgumentList "remove $serviceName confirm" -Wait -NoNewWindow
        Write-Host "Successfully removed the existing CICB-Server service.`n" -ForegroundColor Green
    }catch{
        Write-Host "Failed to remove the existing CICB-Server service: $_`n" -ForegroundColor Red
    }
}


# Stop the existing service
function StopExistingService($nssmPath, $serviceName)
{
    Write-Host "StopExistingService()" -ForegroundColor Yellow
    try {
        Start-Process -FilePath $nssmPath -ArgumentList "stop $serviceName confirm" -Wait -NoNewWindow
        Write-Host "Successfully stopped the existing CICB-Server service.`n" -ForegroundColor Green
    }catch{
        Write-Host "Failed to stop the existing CICB-Server service: $_`n" -ForegroundColor Red
    }
}


# Stop running server.exe
function StopRunningServer($appPath)
{
    Write-Host "StopRunningServer()" -ForegroundColor Yellow
    try {
        Get-Process | Where-Object { $_.Path -eq "$($appPath)" } | Stop-Process -Force
        Write-Host "Successfully stopped running CICB-Server.`n" -ForegroundColor Green
    } catch{
        Write-Host "Failed to stop running CICB-Server: $_`n" -ForegroundColor Red
    }
}


# Install the service
function InstallService ($nssmPath, $serviceName, $appPath)
{
    Write-Host "InstallService()" -ForegroundColor Yellow
    try {
        Start-Process -FilePath $nssmPath -ArgumentList "install $serviceName `"$appPath`"" -Wait -NoNewWindow
        Write-Host "Successfully installed CICB-Server service.`n" -ForegroundColor Green
    }catch{
        Write-Host "Failed to install CICB-Server service: $_`n" -ForegroundColor Red
    }
}


# Set service configuration
function SetServiceConfigurations ($nssmPath, $serviceName, $option)
{
    Write-Host "SetServiceConfigurations()" -ForegroundColor Yellow
    if($option -eq 2){
        $serviceUsername = Read-Host "Enter your service account username"
        $servicePassword = Read-Host "Enter your service account password" -AsSecureString
        Write-Host "Service account username: $serviceUsername" -ForegroundColor Magenta
        Write-Host "Service account password has been securely captured.`n" -ForegroundColor Magenta
        Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName ObjectName `".\$serviceUsername`" `"$servicePassword`"" -Wait -NoNewWindow
    }
    Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName Description `"Cyber Intel Classification Banner - Server Service`"" -Wait -NoNewWindow
    Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName Start SERVICE_AUTO_START" -Wait -NoNewWindow
    Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName AppExit Default Exit" -Wait -NoNewWindow # Default | Restart
    Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName AppStdout `"stdout.log`"" -Wait -NoNewWindow
    Start-Process -FilePath $nssmPath -ArgumentList "set $serviceName AppStdout `"stdout.log`"" -Wait -NoNewWindow
    Start-Process -FilePath $nssmPath -ArgumentList "get $serviceName Application" -Wait -NoNewWindow
}


# Start the service
function StartService($nssmPath, $serviceName)
{
    Write-Host "`nStartService()" -ForegroundColor Yellow
    try {
        Start-Process -FilePath $nssmPath -ArgumentList "start $serviceName" -Wait -NoNewWindow
        # Write-Host "Successfully started CICB-Server service.`n" -ForegroundColor Green
    }catch{
        Write-Host "Failed to start CICB-Server service: $_`n" -ForegroundColor Red
    }
}


# Check service status
function CheckServiceStatus($serviceName)
{
    Write-Host "`nCheckServiceStatus()" -ForegroundColor Yellow
    $res = Get-Service -Name $serviceName -ErrorAction SilentlyContinue
    Write-Host "The CICB-Server service status is $($res.Status)." -ForegroundColor Cyan

    Write-Host "`n`n--------------------------------------------------------`n" -ForegroundColor Yellow
}

Run
# SIG # Begin signature block
# MIIl8AYJKoZIhvcNAQcCoIIl4TCCJd0CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCC6tnD3dvGvrOPI
# 4+F2Xoh6+/ancsgV+5Mi0MbvYZCBVKCCCvwwggMwMIICtqADAgECAhA3dENPnrQO
# Ih+SNsofLycXMAoGCCqGSM49BAMDMFYxCzAJBgNVBAYTAkdCMRgwFgYDVQQKEw9T
# ZWN0aWdvIExpbWl0ZWQxLTArBgNVBAMTJFNlY3RpZ28gUHVibGljIENvZGUgU2ln
# bmluZyBSb290IEU0NjAeFw0yMTAzMjIwMDAwMDBaFw0zNjAzMjEyMzU5NTlaMFcx
# CzAJBgNVBAYTAkdCMRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0ZWQxLjAsBgNVBAMT
# JVNlY3RpZ28gUHVibGljIENvZGUgU2lnbmluZyBDQSBFViBFMzYwWTATBgcqhkjO
# PQIBBggqhkjOPQMBBwNCAATeYxX2c1WJigfhpKs/AWOltt5cfDakxup7PAMZvjm4
# RlCveoj0eC3SThHbqjm6l9fMm3TcXx5+7StE0SzjIMPPo4IBYzCCAV8wHwYDVR0j
# BBgwFoAUz30soJB6mB3dtl6FwuDaFXHS5V4wHQYDVR0OBBYEFBp0pDjXubYOs1v6
# 3F6uP7bwcz2IMA4GA1UdDwEB/wQEAwIBhjASBgNVHRMBAf8ECDAGAQH/AgEAMBMG
# A1UdJQQMMAoGCCsGAQUFBwMDMBoGA1UdIAQTMBEwBgYEVR0gADAHBgVngQwBAzBL
# BgNVHR8ERDBCMECgPqA8hjpodHRwOi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29Q
# dWJsaWNDb2RlU2lnbmluZ1Jvb3RFNDYuY3JsMHsGCCsGAQUFBwEBBG8wbTBGBggr
# BgEFBQcwAoY6aHR0cDovL2NydC5zZWN0aWdvLmNvbS9TZWN0aWdvUHVibGljQ29k
# ZVNpZ25pbmdSb290RTQ2LnA3YzAjBggrBgEFBQcwAYYXaHR0cDovL29jc3Auc2Vj
# dGlnby5jb20wCgYIKoZIzj0EAwMDaAAwZQIxAKB6vcvgJjHZbsfIfO8toCc1571B
# Wo7A6sFhnLKpcREu1mDUOxyx2hhnaCzMRbfNpQIwBou1zB2hXfkAOmu7b3AKFLuQ
# WBe3n30THbvCYv764kIm2HrFivefIXZvZgkMBq07MIIDwjCCAqqgAwIBAgIRANWz
# YAKJWaJ/hGXJ5rGNusswDQYJKoZIhvcNAQEMBQAwezELMAkGA1UEBhMCR0IxGzAZ
# BgNVBAgMEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4GA1UEBwwHU2FsZm9yZDEaMBgG
# A1UECgwRQ29tb2RvIENBIExpbWl0ZWQxITAfBgNVBAMMGEFBQSBDZXJ0aWZpY2F0
# ZSBTZXJ2aWNlczAeFw0yMzAyMjgwMDAwMDBaFw0yODEyMzEyMzU5NTlaMFYxCzAJ
# BgNVBAYTAkdCMRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0ZWQxLTArBgNVBAMTJFNl
# Y3RpZ28gUHVibGljIENvZGUgU2lnbmluZyBSb290IEU0NjB2MBAGByqGSM49AgEG
# BSuBBAAiA2IABAgygQMfjzuib4FHjOV7ubrBabJbScAouRRYbyQzzlCbc9k7wWg5
# nHphzlzSIkdEq4CFqeWVrKquZliGVqe4g4PMtNEOqVH4S2c5f4y5tjloNI8ZSrqO
# IetCuKxWnQncB6OCARIwggEOMB8GA1UdIwQYMBaAFKARCiM+lvEH7OKvKe+CpX/Q
# MKS0MB0GA1UdDgQWBBTPfSygkHqYHd22XoXC4NoVcdLlXjAOBgNVHQ8BAf8EBAMC
# AYYwDwYDVR0TAQH/BAUwAwEB/zATBgNVHSUEDDAKBggrBgEFBQcDAzAbBgNVHSAE
# FDASMAYGBFUdIAAwCAYGZ4EMAQQBMEMGA1UdHwQ8MDowOKA2oDSGMmh0dHA6Ly9j
# cmwuY29tb2RvY2EuY29tL0FBQUNlcnRpZmljYXRlU2VydmljZXMuY3JsMDQGCCsG
# AQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuY29tb2RvY2EuY29t
# MA0GCSqGSIb3DQEBDAUAA4IBAQA3P95PqrMZSfh702kbeiCCoqPEYZFEp6eMi/N5
# jTpv58evyW2wD6VyKLfU+0DsadOR5QLRsdU02tbzprhPwc6hJGIGm54YfQ+E6XiV
# yeDZq31799ITQ0PmTveZdPdwfxxRoLUW7vaMmpErxQTMt/+j9XUAC74+Jo8bI2TN
# KyWwMg7msc80yWN9zgkWH7gRuKZGSWw02lj4XMCKE86mKDjiDEvZYzGG0hh/InEg
# V9O8WOTPxi7XOX5mGaC44I8WZFbxVtpwBt71wlcmqNP58ahN7/VTJZgKiuhcvjqc
# Azr0Hfp+tlJBmiF4KFosnIpz6wM5+LTTFsE7JcIl+5kojtHfMIID/jCCA6WgAwIB
# AgIRALVnRKta1Wj2UMNaJ5u6gZAwCgYIKoZIzj0EAwIwVzELMAkGA1UEBhMCR0Ix
# GDAWBgNVBAoTD1NlY3RpZ28gTGltaXRlZDEuMCwGA1UEAxMlU2VjdGlnbyBQdWJs
# aWMgQ29kZSBTaWduaW5nIENBIEVWIEUzNjAeFw0yNDA0MTUwMDAwMDBaFw0yNzA0
# MTUyMzU5NTlaMIG1MRQwEgYDVQQFEws2MDQgNjk0IDU4OTETMBEGCysGAQQBgjc8
# AgEDEwJVUzEbMBkGCysGAQQBgjc8AgECEwpXYXNoaW5ndG9uMR0wGwYDVQQPExRQ
# cml2YXRlIE9yZ2FuaXphdGlvbjELMAkGA1UEBhMCVVMxEzARBgNVBAgMCldhc2hp
# bmd0b24xFDASBgNVBAoMC0FSS1NPRlQgSU5DMRQwEgYDVQQDDAtBUktTT0ZUIElO
# QzB2MBAGByqGSM49AgEGBSuBBAAiA2IABE5uIa0hg/cpmWbqq9qSPz5sVr+MdfcA
# 934E97Ghkkh6lbK003gu+tnql24GKufvNVq4e+bbRuE2n/+6zcxz0AgnJchoiBcn
# wT/GXNF1UqjDhZLoMxKHcqSDuERbKjVPhaOCAdQwggHQMB8GA1UdIwQYMBaAFBp0
# pDjXubYOs1v63F6uP7bwcz2IMB0GA1UdDgQWBBS6PEfYAUExaS/V6GZWrHPyu23w
# xTAOBgNVHQ8BAf8EBAMCB4AwDAYDVR0TAQH/BAIwADATBgNVHSUEDDAKBggrBgEF
# BQcDAzBJBgNVHSAEQjBAMDUGDCsGAQQBsjEBAgEGATAlMCMGCCsGAQUFBwIBFhdo
# dHRwczovL3NlY3RpZ28uY29tL0NQUzAHBgVngQwBAzBLBgNVHR8ERDBCMECgPqA8
# hjpodHRwOi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNDb2RlU2lnbmlu
# Z0NBRVZFMzYuY3JsMHsGCCsGAQUFBwEBBG8wbTBGBggrBgEFBQcwAoY6aHR0cDov
# L2NydC5zZWN0aWdvLmNvbS9TZWN0aWdvUHVibGljQ29kZVNpZ25pbmdDQUVWRTM2
# LmNydDAjBggrBgEFBQcwAYYXaHR0cDovL29jc3Auc2VjdGlnby5jb20wRgYDVR0R
# BD8wPaApBggrBgEFBQcIA6AdMBsMGVVTLVdBU0hJTkdUT04tNjA0IDY5NCA1ODmB
# EGNlcnRAYXJrc29mdC5kZXYwCgYIKoZIzj0EAwIDRwAwRAIgLQoUvWU23PIdamhN
# yRwLcSmW36EEJ3eGzTi3vH3j9EgCIEBHnMtvgzTUZ+K/ZmfWboe0Ry07z0TM2mT6
# StcjWJhDMYIaSjCCGkYCAQEwbDBXMQswCQYDVQQGEwJHQjEYMBYGA1UEChMPU2Vj
# dGlnbyBMaW1pdGVkMS4wLAYDVQQDEyVTZWN0aWdvIFB1YmxpYyBDb2RlIFNpZ25p
# bmcgQ0EgRVYgRTM2AhEAtWdEq1rVaPZQw1onm7qBkDANBglghkgBZQMEAgEFAKB8
# MBAGCisGAQQBgjcCAQwxAjAAMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEEMBwG
# CisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEiBCA5tDzg
# hcnLbWlz5XzImYOTnBqRcLMbg73ZjXAJbjH22jALBgcqhkjOPQIBBQAEaDBmAjEA
# +f//MHizCc1uxf1eN6eraXmfyCzhp/p6ejtp3aQanfQ+5/nTZc5NiopMY8FNaRvj
# AjEAhoxMQ9dO6UH/lu4Elgb826s3PYSU5qwKX6k3aKgFAFPNeH4h7mwMcpOCDgJG
# NJDFoYIYzTCCGMkGCisGAQQBgjcDAwExghi5MIIYtQYJKoZIhvcNAQcCoIIYpjCC
# GKICAQMxDzANBglghkgBZQMEAgIFADCB8wYLKoZIhvcNAQkQAQSggeMEgeAwgd0C
# AQEGCisGAQQBsjECAQEwMTANBglghkgBZQMEAgEFAAQg7mllKpKnZCgQL02LyDIu
# z4u4irG8XBfboV041tE1H1UCFG/To0ND95o5qYu7kxO3JgAIEnWXGA8yMDI1MDEy
# NDIxNDE0NVqgcqRwMG4xCzAJBgNVBAYTAkdCMRMwEQYDVQQIEwpNYW5jaGVzdGVy
# MRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0ZWQxMDAuBgNVBAMTJ1NlY3RpZ28gUHVi
# bGljIFRpbWUgU3RhbXBpbmcgU2lnbmVyIFIzNaCCEv8wggZdMIIExaADAgECAhA6
# UmoshM5V5h1l/MwS2OmJMA0GCSqGSIb3DQEBDAUAMFUxCzAJBgNVBAYTAkdCMRgw
# FgYDVQQKEw9TZWN0aWdvIExpbWl0ZWQxLDAqBgNVBAMTI1NlY3RpZ28gUHVibGlj
# IFRpbWUgU3RhbXBpbmcgQ0EgUjM2MB4XDTI0MDExNTAwMDAwMFoXDTM1MDQxNDIz
# NTk1OVowbjELMAkGA1UEBhMCR0IxEzARBgNVBAgTCk1hbmNoZXN0ZXIxGDAWBgNV
# BAoTD1NlY3RpZ28gTGltaXRlZDEwMC4GA1UEAxMnU2VjdGlnbyBQdWJsaWMgVGlt
# ZSBTdGFtcGluZyBTaWduZXIgUjM1MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
# CgKCAgEAjdFn9MFIm739OEk6TWGBm8PY3EWlYQQ2jQae45iWgPXUGVuYoIa1xjTG
# Iyuw3suUSBzKiyG0/c/Yn++d5mG6IyayljuGT9DeXQU9k8GWWj2/BPoamg2fFctn
# PsdTYhMGxM06z1+Ft0Bav8ybww21ii/faiy+NhiUM195+cFqOtCpJXxZ/lm9tpjm
# VmEqpAlRpfGmLhNdkqiEuDFTuD1GsV3jvuPuPGKUJTam3P53U4LM0UCxeDI8Qz40
# Qw9TPar6S02XExlc8X1YsiE6ETcTz+g1ImQ1OqFwEaxsMj/WoJT18GG5KiNnS7n/
# X4iMwboAg3IjpcvEzw4AZCZowHyCzYhnFRM4PuNMVHYcTXGgvuq9I7j4ke281x4e
# 7/90Z5Wbk92RrLcS35hO30TABcGx3Q8+YLRy6o0k1w4jRefCMT7b5mTxtq5XPmKv
# tgfPuaWPkGZ/tbxInyNDA7YgOgccULjp4+D56g2iuzRCsLQ9ac6AN4yRbqCYsG2r
# cIQ5INTyI2JzA2w1vsAHPRbUTeqVLDuNOY2gYIoKBWQsPYVoyzaoBVU6O5TG+a1Y
# yfWkgVVS9nXKs8hVti3VpOV3aeuaHnjgC6He2CCDL9aW6gteUe0AmC8XCtWwpePx
# 6QW3ROZo8vSUe9AR7mMdu5+FzTmW8K13Bt8GX/YBFJO7LWzwKAUCAwEAAaOCAY4w
# ggGKMB8GA1UdIwQYMBaAFF9Y7UwxeqJhQo1SgLqzYZcZojKbMB0GA1UdDgQWBBRo
# 76QySWm2Ujgd6kM5LPQUap4MhTAOBgNVHQ8BAf8EBAMCBsAwDAYDVR0TAQH/BAIw
# ADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDBKBgNVHSAEQzBBMDUGDCsGAQQBsjEB
# AgEDCDAlMCMGCCsGAQUFBwIBFhdodHRwczovL3NlY3RpZ28uY29tL0NQUzAIBgZn
# gQwBBAIwSgYDVR0fBEMwQTA/oD2gO4Y5aHR0cDovL2NybC5zZWN0aWdvLmNvbS9T
# ZWN0aWdvUHVibGljVGltZVN0YW1waW5nQ0FSMzYuY3JsMHoGCCsGAQUFBwEBBG4w
# bDBFBggrBgEFBQcwAoY5aHR0cDovL2NydC5zZWN0aWdvLmNvbS9TZWN0aWdvUHVi
# bGljVGltZVN0YW1waW5nQ0FSMzYuY3J0MCMGCCsGAQUFBzABhhdodHRwOi8vb2Nz
# cC5zZWN0aWdvLmNvbTANBgkqhkiG9w0BAQwFAAOCAYEAsNwuyfpPNkyKL/bJT9Xv
# GE8fnw7Gv/4SetmOkjK9hPPa7/Nsv5/MHuVus+aXwRFqM5Vu51qfrHTwnVExcP2E
# HKr7IR+m/Ub7PamaeWfle5x8D0x/MsysICs00xtSNVxFywCvXx55l6Wg3lXiPCui
# 8N4s51mXS0Ht85fkXo3auZdo1O4lHzJLYX4RZovlVWD5EfwV6Ve1G9UMslnm6pI0
# hyR0Zr95QWG0MpNPP0u05SHjq/YkPlDee3yYOECNMqnZ+j8onoUtZ0oC8CkbOOk/
# AOoV4kp/6Ql2gEp3bNC7DOTlaCmH24DjpVgryn8FMklqEoK4Z3IoUgV8R9qQLg1d
# r6/BjghGnj2XNA8ujta2JyoxpqpvyETZCYIUjIs69YiDjzftt37rQVwIZsfCYv+D
# U5sh/StFL1x4rgNj2t8GccUfa/V3iFFW9lfIJWWsvtlC5XOOOQswr1UmVdNWQem4
# LwrlLgcdO/YAnHqY52QwnBLiAuUnuBeshWmfEb5oieIYMIIGFDCCA/ygAwIBAgIQ
# eiOu2lNplg+RyD5c9MfjPzANBgkqhkiG9w0BAQwFADBXMQswCQYDVQQGEwJHQjEY
# MBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMS4wLAYDVQQDEyVTZWN0aWdvIFB1Ymxp
# YyBUaW1lIFN0YW1waW5nIFJvb3QgUjQ2MB4XDTIxMDMyMjAwMDAwMFoXDTM2MDMy
# MTIzNTk1OVowVTELMAkGA1UEBhMCR0IxGDAWBgNVBAoTD1NlY3RpZ28gTGltaXRl
# ZDEsMCoGA1UEAxMjU2VjdGlnbyBQdWJsaWMgVGltZSBTdGFtcGluZyBDQSBSMzYw
# ggGiMA0GCSqGSIb3DQEBAQUAA4IBjwAwggGKAoIBgQDNmNhDQatugivs9jN+JjTk
# iYzT7yISgFQ+7yavjA6Bg+OiIjPm/N/t3nC7wYUrUlY3mFyI32t2o6Ft3EtxJXCc
# 5MmZQZ8AxCbh5c6WzeJDB9qkQVa46xiYEpc81KnBkAWgsaXnLURoYZzksHIzzCNx
# tIXnb9njZholGw9djnjkTdAA83abEOHQ4ujOGIaBhPXG2NdV8TNgFWZ9BojlAvfl
# xNMCOwkCnzlH4oCw5+4v1nssWeN1y4+RlaOywwRMUi54fr2vFsU5QPrgb6tSjvEU
# h1EC4M29YGy/SIYM8ZpHadmVjbi3Pl8hJiTWw9jiCKv31pcAaeijS9fc6R7DgyyL
# IGflmdQMwrNRxCulVq8ZpysiSYNi79tw5RHWZUEhnRfs/hsp/fwkXsynu1jcsUX+
# HuG8FLa2BNheUPtOcgw+vHJcJ8HnJCrcUWhdFczf8O+pDiyGhVYX+bDDP3GhGS7T
# mKmGnbZ9N+MpEhWmbiAVPbgkqykSkzyYVr15OApZYK8CAwEAAaOCAVwwggFYMB8G
# A1UdIwQYMBaAFPZ3at0//QET/xahbIICL9AKPRQlMB0GA1UdDgQWBBRfWO1MMXqi
# YUKNUoC6s2GXGaIymzAOBgNVHQ8BAf8EBAMCAYYwEgYDVR0TAQH/BAgwBgEB/wIB
# ADATBgNVHSUEDDAKBggrBgEFBQcDCDARBgNVHSAECjAIMAYGBFUdIAAwTAYDVR0f
# BEUwQzBBoD+gPYY7aHR0cDovL2NybC5zZWN0aWdvLmNvbS9TZWN0aWdvUHVibGlj
# VGltZVN0YW1waW5nUm9vdFI0Ni5jcmwwfAYIKwYBBQUHAQEEcDBuMEcGCCsGAQUF
# BzAChjtodHRwOi8vY3J0LnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNUaW1lU3Rh
# bXBpbmdSb290UjQ2LnA3YzAjBggrBgEFBQcwAYYXaHR0cDovL29jc3Auc2VjdGln
# by5jb20wDQYJKoZIhvcNAQEMBQADggIBABLXeyCtDjVYDJ6BHSVY/UwtZ3Svx2Im
# IfZVVGnGoUaGdltoX4hDskBMZx5NY5L6SCcwDMZhHOmbyMhyOVJDwm1yrKYqGDHW
# zpwVkFJ+996jKKAXyIIaUf5JVKjccev3w16mNIUlNTkpJEor7edVJZiRJVCAmWAa
# Hcw9zP0hY3gj+fWp8MbOocI9Zn78xvm9XKGBp6rEs9sEiq/pwzvg2/KjXE2yWUQI
# kms6+yslCRqNXPjEnBnxuUB1fm6bPAV+Tsr/Qrd+mOCJemo06ldon4pJFbQd0TQV
# IMLv5koklInHvyaf6vATJP4DfPtKzSBPkKlOtyaFTAjD2Nu+di5hErEVVaMqSVbf
# Pzd6kNXOhYm23EWm6N2s2ZHCHVhlUgHaC4ACMRCgXjYfQEDtYEK54dUwPJXV7icz
# 0rgCzs9VI29DwsjVZFpO4ZIVR33LwXyPDbYFkLqYmgHjR3tKVkhh9qKV2WCmBuC2
# 7pIOx6TYvyqiYbntinmpOqh/QPAnhDgexKG9GX/n1PggkGi9HCapZp8fRwg8Rftw
# S21Ln61euBG0yONM6noD2XQPrFwpm3GcuqJMf0o8LLrFkSLRQNwxPDDkWXhW+gZs
# wbaiie5fd/W2ygcto78XCSPfFWveUOSZ5SqK95tBO8aTHmEa4lpJVD7HrTEn9jb1
# EGvxOb1cnn0CMIIGgjCCBGqgAwIBAgIQNsKwvXwbOuejs902y8l1aDANBgkqhkiG
# 9w0BAQwFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCk5ldyBKZXJzZXkxFDAS
# BgNVBAcTC0plcnNleSBDaXR5MR4wHAYDVQQKExVUaGUgVVNFUlRSVVNUIE5ldHdv
# cmsxLjAsBgNVBAMTJVVTRVJUcnVzdCBSU0EgQ2VydGlmaWNhdGlvbiBBdXRob3Jp
# dHkwHhcNMjEwMzIyMDAwMDAwWhcNMzgwMTE4MjM1OTU5WjBXMQswCQYDVQQGEwJH
# QjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMS4wLAYDVQQDEyVTZWN0aWdvIFB1
# YmxpYyBUaW1lIFN0YW1waW5nIFJvb3QgUjQ2MIICIjANBgkqhkiG9w0BAQEFAAOC
# Ag8AMIICCgKCAgEAiJ3YuUVnnR3d6LkmgZpUVMB8SQWbzFoVD9mUEES0QUCBdxSZ
# qdTkdizICFNeINCSJS+lV1ipnW5ihkQyC0cRLWXUJzodqpnMRs46npiJPHrfLBOi
# fjfhpdXJ2aHHsPHggGsCi7uE0awqKggE/LkYw3sqaBia67h/3awoqNvGqiFRJ+OT
# WYmUCO2GAXsePHi+/JUNAax3kpqstbl3vcTdOGhtKShvZIvjwulRH87rbukNyHGW
# X5tNK/WABKf+Gnoi4cmisS7oSimgHUI0Wn/4elNd40BFdSZ1EwpuddZ+Wr7+Dfo0
# lcHflm/FDDrOJ3rWqauUP8hsokDoI7D/yUVI9DAE/WK3Jl3C4LKwIpn1mNzMyptR
# wsXKrop06m7NUNHdlTDEMovXAIDGAvYynPt5lutv8lZeI5w3MOlCybAZDpK3Dy1M
# Ko+6aEtE9vtiTMzz/o2dYfdP0KWZwZIXbYsTIlg1YIetCpi5s14qiXOpRsKqFKqa
# v9R1R5vj3NgevsAsvxsAnI8Oa5s2oy25qhsoBIGo/zi6GpxFj+mOdh35Xn91y72J
# 4RGOJEoqzEIbW3q0b2iPuWLA911cRxgY5SJYubvjay3nSMbBPPFsyl6mY4/WYucm
# yS9lo3l7jk27MAe145GWxK4O3m3gEFEIkv7kRmefDR7Oe2T1HxAnICQvr9sCAwEA
# AaOCARYwggESMB8GA1UdIwQYMBaAFFN5v1qqK0rPVIDh2JvAnfKyA2bLMB0GA1Ud
# DgQWBBT2d2rdP/0BE/8WoWyCAi/QCj0UJTAOBgNVHQ8BAf8EBAMCAYYwDwYDVR0T
# AQH/BAUwAwEB/zATBgNVHSUEDDAKBggrBgEFBQcDCDARBgNVHSAECjAIMAYGBFUd
# IAAwUAYDVR0fBEkwRzBFoEOgQYY/aHR0cDovL2NybC51c2VydHJ1c3QuY29tL1VT
# RVJUcnVzdFJTQUNlcnRpZmljYXRpb25BdXRob3JpdHkuY3JsMDUGCCsGAQUFBwEB
# BCkwJzAlBggrBgEFBQcwAYYZaHR0cDovL29jc3AudXNlcnRydXN0LmNvbTANBgkq
# hkiG9w0BAQwFAAOCAgEADr5lQe1oRLjlocXUEYfktzsljOt+2sgXke3Y8UPEooU5
# y39rAARaAdAxUeiX1ktLJ3+lgxtoLQhn5cFb3GF2SSZRX8ptQ6IvuD3wz/LNHKpQ
# 5nX8hjsDLRhsyeIiJsms9yAWnvdYOdEMq1W61KE9JlBkB20XBee6JaXx4UBErc+Y
# uoSb1SxVf7nkNtUjPfcxuFtrQdRMRi/fInV/AobE8Gw/8yBMQKKaHt5eia8ybT8Y
# /Ffa6HAJyz9gvEOcF1VWXG8OMeM7Vy7Bs6mSIkYeYtddU1ux1dQLbEGur18ut97w
# gGwDiGinCwKPyFO7ApcmVJOtlw9FVJxw/mL1TbyBns4zOgkaXFnnfzg4qbSvnrwy
# j1NiurMp4pmAWjR+Pb/SIduPnmFzbSN/G8reZCL4fvGlvPFk4Uab/JVCSmj59+/m
# B2Gn6G/UYOy8k60mKcmaAZsEVkhOFuoj4we8CYyaR9vd9PGZKSinaZIkvVjbH/3n
# lLb0a7SBIkiRzfPfS9T+JesylbHa1LtRV9U/7m0q7Ma2CQ/t392ioOssXW7oKLdO
# mMBl14suVFBmbzrt5V5cQPnwtd3UOTpS9oCG+ZZheiIvPgkDmA8FzPsnfXW5qHEL
# B43ET7HHFHeRPRYrMBKjkb8/IN7Po0d0hQoF4TeMM+zYAJzoKQnVKOLg8pZVPT8x
# ggSRMIIEjQIBATBpMFUxCzAJBgNVBAYTAkdCMRgwFgYDVQQKEw9TZWN0aWdvIExp
# bWl0ZWQxLDAqBgNVBAMTI1NlY3RpZ28gUHVibGljIFRpbWUgU3RhbXBpbmcgQ0Eg
# UjM2AhA6UmoshM5V5h1l/MwS2OmJMA0GCWCGSAFlAwQCAgUAoIIB+TAaBgkqhkiG
# 9w0BCQMxDQYLKoZIhvcNAQkQAQQwHAYJKoZIhvcNAQkFMQ8XDTI1MDEyNDIxNDE0
# NVowPwYJKoZIhvcNAQkEMTIEMMzSQ1lc6KHWpd27r3g0ZOCRNeJOKBpOPAooaZGb
# 4QcA94ZvvG9q8vlrrVu0TvIscTCCAXoGCyqGSIb3DQEJEAIMMYIBaTCCAWUwggFh
# MBYEFPhgmBmm+4gs9+hSl/KhGVIaFndfMIGHBBTGrlTkeIbxfD1VEkiMacNKevnC
# 3TBvMFukWTBXMQswCQYDVQQGEwJHQjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVk
# MS4wLAYDVQQDEyVTZWN0aWdvIFB1YmxpYyBUaW1lIFN0YW1waW5nIFJvb3QgUjQ2
# AhB6I67aU2mWD5HIPlz0x+M/MIG8BBSFPWMtk4KCYXzQkDXEkd6SwULaxzCBozCB
# jqSBizCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCk5ldyBKZXJzZXkxFDASBgNV
# BAcTC0plcnNleSBDaXR5MR4wHAYDVQQKExVUaGUgVVNFUlRSVVNUIE5ldHdvcmsx
# LjAsBgNVBAMTJVVTRVJUcnVzdCBSU0EgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkC
# EDbCsL18Gzrno7PdNsvJdWgwDQYJKoZIhvcNAQEBBQAEggIAVvVE4KIq2dZY/LGa
# xqbX5t3PEqSNi/0RP975So3hlZIUaQLpooLyjWfGY3BQ5X4s2lZn7u6H2XewW4Gq
# A3I76vBWzkmThFWOzxp03PLCw6j+LZQXc7LrqlgU/SWHBXV3jcoiemMzWJP8osi5
# uiojW79dLOxrT8JmSbChSSGahCoDOUEYuKBwn6dj7+AL757jEi7OqzZHSEoOZCUF
# cH8ws1ASBQSEinYY2jNsKZzUBQtZBO1WZfpczQ6me4UiKvvFu7VEMtJc5Q6A4kXS
# amOWS1s8BxWPrh0s6zv5DkzxFTjpX5th/9fTDodjfaLB5Jj0F5Ab5Yr0MF8T2RoQ
# NNIeAwEfPO3UeyavO55xQlRUjf5mwfr40OQFftIxPJ3n7HkxQmVWwSGMHbnLJqYX
# JIJv0sr7Ij8dTFgrOAZADTwYZCtZSi8KXh43wydzFgZ+wtjUBl8aBX64+DBaDkwc
# brH+zWVxgQeXXgj6zw/pjOIrNJm6dR8RIekho3l6uuMqkyRV+05HJ9/6UxCEdi6C
# blS0EFaC8FYN/wCaZjCs9MRkbcaqMtMY8ZTT/ACdFYQNUmuN+IGv9TcH1jPEoXOC
# 6DpbMgk8WdMo3wnoIwc8TvA/BXCzh/hRSKNqhkdKYyMM9eqX5Tutw6iHpwlAEx5A
# 3cKDzox42G8hC5GQDYcXqj3sY8w=
# SIG # End signature block
